@@ -9,6 +9,7 @@
 #' @param zero_digits number of significant digits for values rounded to 0 (can be set to NULL to keep the original 0 value)
 #' @param date_format if `x` is a vector of Date or POSIXt, the format to apply (see [strptime] for formats)
 #' @param percent if TRUE, format the values as percentages
+#' @param scientific the power of ten above/under which numbers will be displayed as scientific notation.
 #' @param only_round if TRUE, `format_fixed` simply returns the rounded value. Can be set globally with `options("crosstable_only_round"=TRUE)`.
 #' @param ... unused
 #'
@@ -22,7 +23,7 @@
 #' format_fixed(x, digits=3) #default zero_digits=1
 #' format_fixed(x, digits=3, zero_digits=2)
 #' format_fixed(x, digits=3, zero_digits=NULL)
-#' 
+#'
 #' x_sd = sd(iris$Sepal.Length/10000, na.rm=TRUE)
 #' format_fixed(x_sd, dig=6)
 #' format_fixed(x_sd, dig=3, zero_digits=2) #default only_round=FALSE
@@ -30,29 +31,41 @@
 #' options("crosstable_only_round"=TRUE)
 #' format_fixed(x_sd, dig=3, zero_digits=2) #override default
 #' options("crosstable_only_round"=NULL)
-#' 
+#'
 #' x2 = mtcars$mpg/max(mtcars$mpg)
 #' x2 = c(0.01, 0.1001, 0.500005, 0.00000012)
 #' format_fixed(x2, percent=TRUE, dig=6)
-format_fixed = function(x, digits=1, zero_digits=1, date_format=NULL, 
-                        percent=FALSE, 
+format_fixed = function(x, digits=1, zero_digits=1, date_format=NULL,
+                        percent=FALSE,
+                        scientific=getOption("crosstable_scientific_log", 4),
                         only_round=getOption("crosstable_only_round", FALSE), ...){
   assert_numeric(x)
   assert_numeric(digits)
   assert_logical(percent)
   assert_logical(only_round)
   assert(is.null(zero_digits)||is.na(zero_digits)||is.numeric(zero_digits))
+  scientific = abs(scientific)
   if(is.date(x)){
-    if(!is.null(date_format)) 
+    if(!is.null(date_format))
       return(format(x, date_format))
-    else 
+    else
       return(format(x))
-  } else  {
+  } else {
+    format = "f"
+    sci = any(abs(x)>=10^scientific | (x!=0 & abs(x)<=10^-scientific), na.rm=TRUE)
+    if(sci) format = "e"
     if(percent) x=x*100
-    if(only_round) return(as.character(round(x, digits)))
-    rtn = ifelse(is.na(x), NA_character_, formatC(x, format='f', digits=digits))
-    if(!is.null(zero_digits) && !is.na(zero_digits)){
-      rtn = ifelse(as.numeric(rtn)==0, as.character(signif(x, digits=zero_digits)), rtn)
+    if(only_round) {
+      if(sci){
+        rtn = sprintf(glue("%.{digits}e"), x)
+      } else {
+        rtn = as.character(round(x, digits))
+      }
+    } else {
+      rtn = ifelse(is.na(x), NA_character_, formatC(x, format=format, digits=digits))
+      if(!is.null(zero_digits) && !is.na(zero_digits)){
+        rtn = ifelse(as.numeric(rtn)==0, as.character(signif(x, digits=zero_digits)), rtn)
+      }
     }
     if(percent) rtn=paste0(rtn, "%")
     return(rtn)
@@ -78,18 +91,29 @@ plim = function(p, digits = 4) {
   return(ptxt)
 }
 
+#' Remove missing values
+#'
+#' @param x a vector
+#'
+#' @return the same vector without missing values
+#' @export
+narm = function(x){
+  x[!is.na(x)]
+}
+
+
 
 # Summary functions --------------------------------------------------------
 
 
 #' Summary functions
-#' 
+#'
 #' Summary functions to use with [crosstable()] or anywhere else.
 #'
 #' @section Fixed format:
 #' These functions use [format_fixed()] which allows to have trailing zeros after rounded values.
-#' In the case when the output of rounded values is zero, the use of the \code{zero_digits} argument allows to keep some significant digits for this specific case only. 
-#' 
+#' In the case when the output of rounded values is zero, the use of the \code{zero_digits} argument allows to keep some significant digits for this specific case only.
+#'
 #' @param x a numeric vector
 #' @param na.rm \code{TRUE} as default
 #' @param dig number of digits
@@ -98,20 +122,20 @@ plim = function(p, digits = 4) {
 #'  \item `zero_digits` (default=`1`): the number of significant digits for values rounded to 0 (set to NULL to keep the original 0 value)
 #'  \item `only_round` (default=`FALSE`): use [round()] instead of [format_fixed()]
 #' }
-#' 
+#'
 #' @return a character vector
-#' 
-#' 
-#' @examples 
+#'
+#'
+#' @examples
 #' meansd(iris$Sepal.Length, dig=3)
 #' meanCI(iris$Sepal.Length)
 #' minmax(iris$Sepal.Length, dig=3)
 #' mediqr(iris$Sepal.Length, dig=3)
 #' nna(iris$Sepal.Length)
-#' 
+#'
 #' #arguments for format_fixed
-#' x = iris$Sepal.Length/10000 #closer to zero 
-#' 
+#' x = iris$Sepal.Length/10000 #closer to zero
+#'
 #' meansd(x, dig=3)
 #' meansd(x, dig=3, zero_digits=NULL) #or NA
 #' meansd(x, dig=3, only_round=TRUE)
@@ -119,16 +143,16 @@ plim = function(p, digits = 4) {
 #' meansd(x, dig=3, zero_digits=2)
 #' options("crosstable_only_round"=NULL)
 #' meanCI(mtcars2$x_date)
-#' 
+#'
 #' #dates
 #' x = as.POSIXct(mtcars$qsec*3600*24 , origin="2010-01-01")
 #' meansd(x)
 #' minmax(x, date_format="%d/%m/%Y")
 #'
 #' @author Dan Chaltiel, David Hajage
-#' 
+#'
 #' @seealso [format_fixed()]
-#' 
+#'
 #' @name summaryFunctions
 NULL
 
@@ -140,19 +164,19 @@ NULL
 #' @author Dan Chaltiel, David Hajage
 #' @export
 meansd = function(x, na.rm = TRUE, dig = 2, ...) {
-  moy = mean(x, na.rm=na.rm) %>% 
+  moy = mean(x, na.rm=na.rm) %>%
     format_fixed(digits=dig, ...)
   if(is.date(x)){
-    if("date_unit" %in% names(list(...))) 
-      date_unit=list(...)$date_unit 
-    else 
+    if("date_unit" %in% names(list(...)))
+      date_unit=list(...)$date_unit
+    else
       date_unit="auto"
     std = sd_date(x, date_unit)
-    std = std$value %>% 
-      format_fixed(digits=dig, ...) %>% 
+    std = std$value %>%
+      format_fixed(digits=dig, ...) %>%
       paste(std$unit)
   } else {
-    std = sd(x, na.rm=na.rm) %>% 
+    std = sd(x, na.rm=na.rm) %>%
       format_fixed(digits=dig, ...)
   }
   paste0(moy, " (", std, ")")
@@ -172,9 +196,9 @@ moystd=function(...){
 #' @author Dan Chaltiel, David Hajage
 #' @export
 meanCI = function(x, na.rm = TRUE, dig = 2, level=0.95, format=TRUE, ...) {
-  .mean = mean(x, na.rm=na.rm) %>% 
+  .mean = mean(x, na.rm=na.rm) %>%
     format_fixed(digits=dig, ...)
-  conf = confint_numeric(x, level=level) %>% 
+  conf = confint_numeric(x, level=level) %>%
     format_fixed(digits=dig, ...)
   if(!format) return(list(mean=.mean, conf_low=conf[1], conf_high=conf[2]))
   paste0(.mean, " [", conf[1], ";", conf[2],  "]")
@@ -191,11 +215,11 @@ meanCI = function(x, na.rm = TRUE, dig = 2, level=0.95, format=TRUE, ...) {
 #' @importFrom stats median quantile
 mediqr = function(x, na.rm = TRUE, dig = 2, format=TRUE, ...) {
   if(is.date(x)) type=1 else type=7
-  med = x %>% 
-    median(na.rm=na.rm) %>% 
+  med = x %>%
+    median(na.rm=na.rm) %>%
     format_fixed(digits=dig, ...)
-  iqr = x %>% 
-    quantile(probs=c(0.25, 0.75), na.rm=na.rm, type=type) %>% 
+  iqr = x %>%
+    quantile(probs=c(0.25, 0.75), na.rm=na.rm, type=type) %>%
     format_fixed(digits=dig, ...)
   if(!format) return(list(med=med, iqr_low=iqr[1], iqr_high=iqr[2]))
   paste0(med, " [", iqr[1], ";", iqr[2], "]")
@@ -247,24 +271,24 @@ na = function(x) {
 }
 
 #' Summarize a numeric vector
-#' 
+#'
 #' Summarize a numeric vector with min, max, mean, sd, median, IQR, n and missings.
 #'
 #' @param x a numeric vector
 #' @param dig number of digits
 #' @param ... params to pass on to [format_fixed()]: `zero_digits` and `only_round`
-#' 
+#'
 #' @return a list of named functions
 #'
 #' @author Dan Chaltiel, David Hajage
 #' @export
-#' @examples 
+#' @examples
 #' cross_summary(iris$Sepal.Length)
 #' cross_summary(iris$Petal.Width, dig=3)
 #' cross_summary(mtcars2$hp_date)
 #' cross_summary(mtcars2$qsec_posix, date_format="%d/%m %H:%M")
 cross_summary = function(x, dig=1, ...) {
-  return(c("Min / Max" = minmax(x, dig=dig, ...), "Med [IQR]" = mediqr(x, dig=dig, ...), 
+  return(c("Min / Max" = minmax(x, dig=dig, ...), "Med [IQR]" = mediqr(x, dig=dig, ...),
            "Mean (std)" = meansd(x, dig=dig, ...), "N (NA)" = nna(x)))
 }
 
